save_naming

Function save_naming 

pub fn save_naming<I, N>(naming: &N, nodes: I) -> Result<PathBuf>
where N: NamingConvention, I: Iterator<Item = Result<SureNode>>,
Write a sure iterator to a new temp file with a given naming convention. Returns the name of the file, if it could be created. The data will not be written compressed.